@@ -26,93 +26,81 @@ import (
 	"io/ioutil"
 	"os"
 	"path/filepath"
+	"strings"
 )
 
-var ErrEmptyPath = errors.New("no path specified")
-
 type history struct {
-	Path string
+	path  string
+	Items []string
 }
 
-func (h *history) Add(expression string) error {
-	if expression == "" {
-		return nil
-	}
+func (h *history) Init(path string) error {
+	h.path = path
 
-	if h.Path == "" {
-		return ErrEmptyPath
-	}
-
-	saved, err := h.Get()
+	filebytes, err := ioutil.ReadFile(path)
 	if err != nil {
-		return err
+		// If the history file doesn't exist, then
+		// return an empty history.
+		if errors.Is(err, os.ErrNotExist) {
+			return nil
+		} else {
+			return fmt.Errorf("error retrieving history: %w", err)
+		}
 	}
 
-	// Don't cotinue with adding the expression if
-	// it is saved in history already.
-	if contains(saved, expression) {
-		return nil
+	scanner := bufio.NewScanner(bytes.NewReader(filebytes))
+	for scanner.Scan() {
+		h.Items = append(h.Items, scanner.Text())
 	}
 
-	file, err := h.openFile()
-	if err != nil {
+	if err := scanner.Err(); err != nil {
 		return fmt.Errorf(
-			"error opening history for writing: %w", err,
-		)
-	}
-
-	fmt.Fprintln(file, expression)
-
-	if err = file.Close(); err != nil {
-		return fmt.Errorf(
-			"error closing history file: %w", err,
+			"error retrieving history: %w", err,
 		)
 	}
 
 	return nil
 }
 
-func (h *history) Get() ([]string, error) {
-	var expressions []string
+func (h *history) Add(expression string) error {
+	expression = strings.TrimSpace(expression)
+	if expression == "" {
+		return nil
+	}
 
-	filebytes, err := ioutil.ReadFile(h.Path)
+	if h.path == "" {
+		return nil
+	}
+
+	// Don't continue with adding the expression if it is saved in history
+	// already.
+	if contains(h.Items, expression) {
+		return nil
+	}
+
+	h.Items = append(h.Items, expression)
+
+	file, err := h.openFile()
 	if err != nil {
-		// If the history file doesn't exist, then
-		// return an empty history.
-		if errors.Is(err, os.ErrNotExist) {
-			return expressions, nil
-		} else {
-			return nil, fmt.Errorf(
-				"error retrieving history: %w", err,
-			)
-		}
+		return fmt.Errorf("error opening history for writing: %w", err)
 	}
 
-	scanner := bufio.NewScanner(bytes.NewReader(filebytes))
-	for scanner.Scan() {
-		expressions = append(expressions, scanner.Text())
+	fmt.Fprintln(file, expression)
+
+	if err = file.Close(); err != nil {
+		return fmt.Errorf("error closing history file: %w", err)
 	}
 
-	if err := scanner.Err(); err != nil {
-		return nil, fmt.Errorf(
-			"error retrieving history: %w", err,
-		)
-	}
-
-	return expressions, nil
+	return nil
 }
 
 func (h *history) openFile() (*os.File, error) {
-	err := os.MkdirAll(filepath.Dir(h.Path), os.ModePerm)
+	err := os.MkdirAll(filepath.Dir(h.path), os.ModePerm)
 	if err != nil {
 		return nil, err
 	}
 
-	f, err := os.OpenFile(
-		h.Path,
-		os.O_WRONLY|os.O_CREATE|os.O_APPEND,
-		0644,
-	)
+	f, err := os.OpenFile(h.path, os.O_WRONLY|os.O_CREATE|os.O_APPEND, 0644)
 	if err != nil {
 		return nil, err
 	}
